/* BEGIN_OF manual part of ccm script file (important, change with care):
// simple triangular lattice
// written by Sven Krueger
//
// LSUB4, restr=1  (Eg and M same as with Sven's old code,
//                  Gap: no comparison)
//   Eg=-0.534266734850  M=0.363657913024  Gap=0.792378897297
//
// control parameters
output level= 1
find generalised expectation values= 0
// solve parameters now
minimum=         1.00
maximum=         2.00
increment=       2.10
minimumy=        0.00
maximumy=        5.00
// other higher level parameters
dimension=  2
spin=       0.5
bounding=  10
n=    4
m=    4
bonds=    1
restriction=1  // 1=no restriction, 2=even flips, 3=user defined, 4=lenght>1
solution strategy=1 // 1=NewtRaphson(seriell), 2=DirectIt(parallel)
// the unit cell
number=1
       0.0        0.0        0.0        0.5
// the Bravais lattice
=      1.0        0.0               0.0
       0.5        0.866025403784439 0.0
       0.0        0.0               1.0
//  Bravis: (1,0), (1/2,sqrt(3)/2)
//  unit cell (with bravis):
//
//      -1.5  -1 -.5  0   .5  1  1.5
//
//  1.732     c ----- a ----- b      
//          /   \   /   \   /   \    
//  0.866 a ----- b ----- c ----- a        ^ a2=(1/2,sqrt(3)/2)
//          \   /   \   /   \   /         /
//  0.000     c ----- A ----- b          o------> a1=(0,1)
//              \   /   \   /   
// -0.866         b ----- c    
//
// END_OF manual part of ccm script file
*/

#include <math.h>

int n_si = 1;    /* number of sites in unit cell */
int n_nn = 6;    /* number of nearest neighb. of each site */
int digits = 15; /* number of digits in float numbers, max 15 */
int directional = 1;  /* has to be 1 here */

struct {
  int nn[4];     /* transl x y z (bravis base) idx_site_inUnitCell */
  double angle;  /* angle (positive) between spins separated by transl vector */
  double value;  /* value of the bond */
  int direct;    /* indicates directionality:  1: -->    -1: <--   (only for directional=1) */
} bond[50] = { { { 1, 0, 0,  1},  2*M_PI/3, 1.0,  1 },
               { { 0, 1, 0,  1}, -2*M_PI/3, 1.0, -1 },
               { {-1, 1, 0,  1},  2*M_PI/3, 1.0,  1 },
               { {-1, 0, 0,  1}, -2*M_PI/3, 1.0, -1 },
               { { 0,-1, 0,  1},  2*M_PI/3, 1.0,  1 },
               { { 1,-1, 0,  1}, -2*M_PI/3, 1.0, -1 },};

#include "genScript2.c"

int main(int argc, char *argv[])
{ int i,si; double faktor, tr[2] = {0.0, 0.0}; char str[200];

  setvbuf(stdout,(char*)NULL,_IONBF,0);    /* everything with fflush(stdout) */

  sprintf(str,"grep -v \"sprintf(str\" %s|grep -B 1000 END_OF|grep -v BEGIN_OF",__FILE__);
  system(str);
    
  printf("//\n// here starts AUTOMATIC generation by %s:\n",__FILE__);
#ifdef USR_FILE
  printf("//\n// ***** NOTE: use USR_FILE  %s  *****\n//\n",USR_FILE);
#else
  printf("//\n");
#endif
  printf("// the nearest-neighbours to each site in the unit cell\n");
  printf("// translation  x y z  (in bravis base)   idx_site_inUnitCell\n");
  for (si=1;si<=n_si;si++) {
    printf("number=  %d  // nn of site %d\n",n_nn,si);
    for (i=0;i<n_nn;i++) {print_nn(si,i); printf("\n");}
  }

  printf("// symmetry operations in Cartesian coordinates\n");
  printf("// point symmetry (3x3 matrix)   translation vector\n");
  printf("number= 6\n");
  rot(0.0,tr,"");               // x-->x,      y-->y
  rot(2*M_PI/3,tr,"");
  rot(4*M_PI/3,tr,"");
  ref(0.0,tr,"refl x-axis");
  ref(M_PI/3,tr,"");
  ref(2*M_PI/3,tr,"");
  
  printf("// Information regardin the Hamiltonian in terms of:\n");
  printf("// Hamiltonian types.\n");
  if (directional==0) faktor=0.5;  /* because of double bond counting */
  else                faktor=1.0;
  printf("directional=%d\n",directional);
  printf("// just one type of bonds\n");
  print_term("bond site 1",1,"111111",faktor);
  

  return 0;
}
